# Feature stages

Some Coder features are released in feature stages before they are generally
available.

If you encounter an issue with any Coder feature, please submit a
[GitHub issues](https://github.com/coder/coder/issues) or join the
[Coder Discord](https://discord.gg/coder).

## Early access features

Early access features are neither feature-complete nor stable. We do not
recommend using early access features in production deployments.

Coder releases early access features behind an “unsafe” experiment, where
they’re accessible but not easy to find.

## Experimental features

These features are disabled by default, and not recommended for use in
production as they may cause performance or stability issues. In most cases,
experimental features are complete, but require further internal testing and
will stay in the experimental stage for one month.

Coder may make significant changes to experiments or revert features to a
feature flag at any time.

If you plan to activate an experimental feature, we suggest that you use a
staging deployment.

You can opt-out of an experiment after you've enabled it.

```yaml
# Enable all experimental features
coder server --experiments=*

# Enable multiple experimental features
coder server --experiments=feature1,feature2

# Alternatively, use the `CODER_EXPERIMENTS` environment variable.
```

### Available experimental features

<!-- Code generated by scripts/release/docs_update_experiments.sh. DO NOT EDIT. -->
<!-- BEGIN: available-experimental-features -->

| Feature         | Description                                                         | Available in |
|-----------------|---------------------------------------------------------------------|--------------|
| `notifications` | Sends notifications via SMTP and webhooks following certain events. | stable       |

<!-- END: available-experimental-features -->

## Beta

Beta features are open to the public, but are tagged with a `Beta` label.

They’re subject to minor changes and may contain bugs, but are generally ready
for use.

## General Availability (GA)

All other features have been tested, are stable, and are enabled by default.
